@@ -397,6 +397,9 @@ class DynFeedbackValue(IntEnum):
     SHOW_FIVE_LEGS = 2,
     SHOW_THREE_LEGS = 1,
     UNDEFINED = -2147483648,
+class EmfRenderSetting(IntEnum):
+    EMF_ONLY = 0,
+    EMF_PLUS_PREFER = 1,
 class FileFormatType(IntEnum):
     CSV = 10,
     DIF = 27,
@@ -420,6 +423,7 @@ class FileFormatType(IntEnum):
     PPSX = 39,
     PPT = 29,
     PPTM = 36,
+    PPTX = 47,
     SLDX = 46,
     SVG = 25,
     TAB_DELIMITED = 16,
@@ -932,6 +936,19 @@ class PresetCameraType(IntEnum):
     PERSPECTIVE_RELAXED = 59,
     PERSPECTIVE_RELAXED_MODERATELY = 60,
     PERSPECTIVE_RIGHT = 61,
+class PresetColorMatricsValue(IntEnum):
+    COLOR_1 = 200,
+    COLOR_2 = 201,
+    COLOR_3 = 202,
+    COLOR_4 = 203,
+    COLOR_5 = 204,
+    COLOR_6 = 205,
+    COLOR_7 = 206,
+class PresetQuickStyleValue(IntEnum):
+    VARIANT_STYLE_1 = 100,
+    VARIANT_STYLE_2 = 101,
+    VARIANT_STYLE_3 = 102,
+    VARIANT_STYLE_4 = 103,
 class PresetShadowType(IntEnum):
     BELOW = 22,
     CUSTOM = 1,
@@ -958,6 +975,46 @@ class PresetShadowType(IntEnum):
     PERSPECTIVE_DIAGONAL_LOWER_RIGHT = 24,
     PERSPECTIVE_DIAGONAL_UPPER_LEFT = 20,
     PERSPECTIVE_DIAGONAL_UPPER_RIGHT = 21,
+class PresetStyleMatricsValue(IntEnum):
+    STYLE_1 = 1,
+    STYLE_2 = 2,
+    STYLE_3 = 3,
+    STYLE_4 = 4,
+    STYLE_5 = 5,
+    STYLE_6 = 6,
+class PresetThemeValue(IntEnum):
+    BUBBLE = 46,
+    CLOUDS = 47,
+    DAYBREAK = 39,
+    FACET = 50,
+    GEMSTONE = 48,
+    INTEGRAL = 36,
+    ION = 43,
+    LINEAR = 34,
+    LINES = 49,
+    MARKER = 57,
+    NO_THEME = 0,
+    OFFICE = 33,
+    ORGANIC = 45,
+    PARALLEL = 40,
+    PEN = 56,
+    PENCIL = 55,
+    PROMINENCE = 51,
+    RADIANCE = 53,
+    RETROSPECT = 44,
+    SEQUENCE = 41,
+    SHADE = 54,
+    SIMPLE = 37,
+    SLICE = 42,
+    SMOKE = 52,
+    WHISP = 38,
+    WHITE_BOARD = 58,
+    ZEPHYR = 35,
+class PresetThemeVariantValue(IntEnum):
+    VARIANT_1 = 0,
+    VARIANT_2 = 1,
+    VARIANT_3 = 2,
+    VARIANT_4 = 3,
 class PreviewScopeValue(IntEnum):
     ALL_PAGES = 2,
     FIRST_PAGE = 0,
@@ -1153,6 +1210,7 @@ class ShapeShdwShowValue(IntEnum):
     TOP_LEVEL_SHOW = 1,
     UNDEFINED = -2147483648,
 class ShapeShdwTypeValue(IntEnum):
+    INNER = 3,
     OBLIQUE = 2,
     SIMPLE = 1,
     UNDEFINED = -2147483648,
@@ -1426,6 +1484,7 @@ from com.aspose.diagram import FontConfigs
 from com.aspose.diagram import Geom
 from com.aspose.diagram import GlueType
 from com.aspose.diagram import GradientStop
+from com.aspose.diagram import GraphicsPathConverter
 from com.aspose.diagram import GridDensity
 from com.aspose.diagram import HorzAlign
 from com.aspose.diagram import HTMLSaveOptions
@@ -1434,6 +1493,7 @@ from com.aspose.diagram import ImageAttributes
 from com.aspose.diagram import ImageSaveOptions
 from com.aspose.diagram import IndividualFontConfigs
 from com.aspose.diagram import InfiniteLine
+from com.aspose.diagram import InterruptMonitor
 from com.aspose.diagram import IntValue
 from com.aspose.diagram import Issue
 from com.aspose.diagram import IssueTarget
@@ -1476,6 +1536,7 @@ from com.aspose.diagram import Pos
 from com.aspose.diagram import Pp
 from com.aspose.diagram import PreviewScope
 from com.aspose.diagram import PrintPageOrientation
+from com.aspose.diagram import PrintSaveOptions
 from com.aspose.diagram import Prop
 from com.aspose.diagram import RelCubBezTo
 from com.aspose.diagram import RelEllipticalArcTo
